@@ -3,15 +3,17 @@ import logging
 import os.path
 import pathlib
 import random
-
-from vision_datasets import DatasetRegistry, Usages, DatasetHub, DatasetTypes
-
+import json
+from tqdm import tqdm
+from vision_datasets import DatasetRegistry, Usages, DatasetHub, DatasetTypes, ManifestDataset
 logger = logging.getLogger(__name__)
 logging.basicConfig(level=logging.INFO)
 
 
 def show_dataset_stats(dataset):
-    logger.info(f'Dataset stats: #images {len(dataset)}, #tags {len(dataset.labels)}')
+    logger.info(f'Dataset stats: #images {len(dataset)}')
+    if dataset.labels:
+        logger.info(f'Dataset stats: #tags {len(dataset.labels)}')
 
 
 def show_img(sample):
@@ -25,14 +27,26 @@ def logging_prefix(dataset_name, version):
     return f'Dataset check {dataset_name}, version {version}: '
 
 
-def check_dataset(dataset):
+def quick_check_images(dataset: ManifestDataset):
     show_dataset_stats(dataset)
     for idx in random.sample(range(len(dataset)), min(10, len(dataset))):
         show_img(dataset[idx])
 
-    if dataset.dataset_info.type in [DatasetTypes.IMCAP, DatasetTypes.MULTITASK, DatasetTypes.IMAGE_TEXT_MATCHING, DatasetTypes.IMAGE_MATTING] or not dataset.labels:
-        return
 
+def check_images(dataset: ManifestDataset, err_msg_file: pathlib.Path):
+    show_dataset_stats(dataset)
+    file_not_found_list = []
+    for i in tqdm(range(len(dataset)), 'Checking image access..'):
+        try:
+            _ = dataset[i]
+        except (KeyError, FileNotFoundError) as e:
+            file_not_found_list.append(str(e))
+
+    if file_not_found_list:
+        err_msg_file.write_text('\n'.join(file_not_found_list))
+
+
+def classification_detection_check(dataset):
     n_imgs_by_class = {x: 0 for x in range(len(dataset.labels))}
     for sample in dataset.dataset_manifest.images:
         labels = sample.labels
@@ -63,18 +77,48 @@ def check_dataset(dataset):
     logger.info(str(stats))
 
 
+def _generate_reg_json(name, type, coco_path):
+    data_info = [
+        {
+            'name': name,
+            'version': 1,
+            'type': type,
+            'format': 'coco',
+            'root_folder': '',
+            'train': {
+                'index_path': coco_path.name
+            }
+        }
+    ]
+
+    return json.dumps(data_info)
+
+
 def main():
     parser = argparse.ArgumentParser('Check if a dataset is valid')
-    parser.add_argument('name', type=str, help="Dataset name.")
-    parser.add_argument('--reg_json', '-r', type=str, default=None, help="dataset registration json file path.", required=True)
-    parser.add_argument('--version', '-v', type=int, help="Dataset version.", default=None)
-    parser.add_argument('--blob_container', '-k', type=str, help="blob container (sas) url", required=False)
-    parser.add_argument('--folder_to_check', '-f', type=str, required=False, help="Check the dataset in this folder.")
+    parser.add_argument('name', type=str, help='Dataset name.')
+    parser.add_argument('--reg_json', '-r', type=pathlib.Path, default=None, help='dataset registration json file path.', required=False)
+    parser.add_argument('--version', '-v', type=int, help='Dataset version.', default=None)
+
+    parser.add_argument('--coco_json', '-c', type=pathlib.Path, default=None, help='Single coco json file to check.', required=False)
+    parser.add_argument('--data_type', '-t', type=str, default=None, help='Type of data.', choices=DatasetTypes.VALID_TYPES, required=False)
+
+    parser.add_argument('--blob_container', '-k', type=str, help='Blob container (sas) url', required=False)
+    parser.add_argument('--folder_to_check', '-f', type=pathlib.Path, required=False, help='Check the dataset in this folder.')
+    parser.add_argument('--quick_check', '-q', action='store_true', default=False, help='Randomly check a few data samples from the dataset.')
 
     args = parser.parse_args()
     prefix = logging_prefix(args.name, args.version)
 
-    data_reg_json = pathlib.Path(args.reg_json).read_text()
+    if args.reg_json:
+        usages = [Usages.TRAIN_PURPOSE, Usages.VAL_PURPOSE, Usages.TEST_PURPOSE]
+        data_reg_json = args.reg_json.read_text()
+    else:
+        assert args.coco_json, '--coco_json not provided'
+        assert args.data_type, '--data_type not provided'
+        usages = [Usages.TRAIN_PURPOSE]
+        data_reg_json = _generate_reg_json(args.name, args.data_type, args.coco_json)
+
     dataset_info = DatasetRegistry(data_reg_json).get_dataset_info(args.name, args.version)
     if not dataset_info:
         logger.error(f'{prefix} dataset does not exist.')
@@ -84,15 +128,19 @@ def main():
 
     vision_datasets = DatasetHub(data_reg_json)
 
-    for usage in [Usages.TRAIN_PURPOSE, Usages.VAL_PURPOSE, Usages.TEST_PURPOSE]:
+    for usage in usages:
         logger.info(f'{prefix} Check dataset with usage: {usage}.')
-        if args.folder_to_check and not os.path.exists(args.folder_to_check):
+        if args.folder_to_check and not args.folder_to_check.exists():
             os.mkdir(args.folder_to_check)
 
         # if args.folder_to_check is none, then this check will directly try to access data from azure blob. Images must be present in uncompressed folder on azure blob.
         dataset = vision_datasets.create_manifest_dataset(container_sas=args.blob_container, local_dir=args.folder_to_check, name=dataset_info.name, version=args.version, usage=usage)
         if dataset:
-            check_dataset(dataset)
+            err_msg_file = pathlib.Path(f'{args.name}_{usage}_errors.txt')
+            if args.quick_check:
+                quick_check_images(dataset)
+            else:
+                check_images(dataset, err_msg_file)
         else:
             logger.info(f'{prefix} No split for {usage} available.')
 
